==> dnv_bladed_models-0.3.32.tar.gz: dnv_bladed_models-0.3.32/src/dnv_bladed_models/transducer_faults.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401

from dnv_bladed_models.dnv import Dnv


class TransducerFaults_FaultTypeEnum(str, Enum):
    NONE = "None"
    NOISE = "Noise"
    TO_CONSTANT = "ToConstant"
    CONSTANT_OFFSET = "ConstantOffset"
    GROWING_OFFSET = "GrowingOffset"
    HARMONIC_OFFSET = "HarmonicOffset"

class TransducerFaults(Dnv):
    """TransducerFaults - 

    Attributes:
        - ApplyOnlyToFirst: bool => If true, the fault will be aplied only to the first instance of this transducer.  If false, all sensors of this type will fail identically.
        - MiscalibrationOffset: float => A constant value added to the sensor&#39;s output - for example, if the sensor had been incorrectly installed or poorly calibrated.
        - InverseInstallation: bool => Whether the sensor was installed in reverse, resulting in its outputs being multiplied by -1.0.
        - FailTime: float => A number representing a time.  The SI units for time are seconds.
        - FaultType: TransducerFaults_FaultTypeEnum => What fault occurs at a specified time in the simulation.
        - NoiseMultiplier: float => A number representing a fraction, ratio, or other non-dimensionalised property.
        - FailureValue: float => The value which the sensor reverts to in the case of failure.
        - FailureValueRampRate: float => The rate at which the signal reverts to its fail value.  A rate of 0.0 represents an instantaneous step change to the fail value.
        - ConstantOffset: float => The value by which the signal is offset by.
        - GrowingOffset: float => The rate at which the signal is deviating from its calibrated value.
        - Magnitude: float => The greatest magnitude of the harmonic interference from the &#39;true&#39; value.
        - Period: float => A number representing a time.  The SI units for time are seconds.
    """

    ApplyOnlyToFirst: Optional[bool] = Field(alias="ApplyOnlyToFirst", default=True)
    MiscalibrationOffset: Optional[float] = Field(alias="MiscalibrationOffset", default=0.0)
    InverseInstallation: Optional[bool] = Field(alias="InverseInstallation", default=False)
    FailTime: Optional[float] = Field(alias="FailTime", default=None)
    FaultType: Optional[TransducerFaults_FaultTypeEnum] = Field(alias="FaultType", default='None')
    NoiseMultiplier: Optional[float] = Field(alias="NoiseMultiplier", default=None)
    FailureValue: Optional[float] = Field(alias="FailureValue", default=0.0)
    FailureValueRampRate: Optional[float] = Field(alias="FailureValueRampRate", default=0.0)
    ConstantOffset: Optional[float] = Field(alias="ConstantOffset", default=0.0)
    GrowingOffset: Optional[float] = Field(alias="GrowingOffset", default=0.0)
    Magnitude: Optional[float] = Field(alias="Magnitude", default=0.0)
    Period: Optional[float] = Field(alias="Period", default=None)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    @root_validator(pre=True)
    def parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        TransducerFaults
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = TransducerFaults.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        TransducerFaults
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = TransducerFaults.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        TransducerFaults
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

TransducerFaults.update_forward_refs()

==> dnv_bladed_models-0.3.44.tar.gz: dnv_bladed_models-0.3.44/src/dnv_bladed_models/transducer_faults.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401


from dnv_bladed_models.dnv import Dnv


class TransducerFaults_FaultTypeEnum(str, Enum):
    NONE = "None"
    NOISE = "Noise"
    TO_CONSTANT = "ToConstant"
    CONSTANT_OFFSET = "ConstantOffset"
    GROWING_OFFSET = "GrowingOffset"
    HARMONIC_OFFSET = "HarmonicOffset"

class TransducerFaults(Dnv):
    """TransducerFaults - 
    
    Attributes:
    ----------
    ApplyOnlyToFirst : bool, default=True
        If true, the fault will be aplied only to the first instance of this transducer.  If false, all sensors of this type will fail identically.
    MiscalibrationOffset : float, default=0.0
        A constant value added to the sensor's output - for example, if the sensor had been incorrectly installed or poorly calibrated.
    InverseInstallation : bool, default=False
        Whether the sensor was installed in reverse, resulting in its outputs being multiplied by -1.0.
    FailTime : float
        A number representing a time.  The SI units for time are seconds.
    FaultType : TransducerFaults_FaultTypeEnum, default='None'
        What fault occurs at a specified time in the simulation.
    NoiseMultiplier : float
        A number representing a fraction, ratio, or other non-dimensionalised property.
    FailureValue : float, default=0.0
        The value which the sensor reverts to in the case of failure.
    FailureValueRampRate : float, default=0.0
        The rate at which the signal reverts to its fail value.  A rate of 0.0 represents an instantaneous step change to the fail value.
    ConstantOffset : float, default=0.0
        The value by which the signal is offset by.
    GrowingOffset : float, default=0.0
        The rate at which the signal is deviating from its calibrated value.
    Magnitude : float, default=0.0
        The greatest magnitude of the harmonic interference from the 'true' value.
    Period : float
        A number representing a time.  The SI units for time are seconds.
    
    """

    ApplyOnlyToFirst: Optional[bool] = Field(alias="ApplyOnlyToFirst", default=True)
    MiscalibrationOffset: Optional[float] = Field(alias="MiscalibrationOffset", default=0.0)
    InverseInstallation: Optional[bool] = Field(alias="InverseInstallation", default=False)
    FailTime: Optional[float] = Field(alias="FailTime", default=None)
    FaultType: Optional[TransducerFaults_FaultTypeEnum] = Field(alias="FaultType", default='None')
    NoiseMultiplier: Optional[float] = Field(alias="NoiseMultiplier", default=None)
    FailureValue: Optional[float] = Field(alias="FailureValue", default=0.0)
    FailureValueRampRate: Optional[float] = Field(alias="FailureValueRampRate", default=0.0)
    ConstantOffset: Optional[float] = Field(alias="ConstantOffset", default=0.0)
    GrowingOffset: Optional[float] = Field(alias="GrowingOffset", default=0.0)
    Magnitude: Optional[float] = Field(alias="Magnitude", default=0.0)
    Period: Optional[float] = Field(alias="Period", default=None)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    @root_validator(pre=True)
    def _parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        TransducerFaults
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = TransducerFaults.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        TransducerFaults
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = TransducerFaults.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        TransducerFaults
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

TransducerFaults.update_forward_refs()
